@@ -1,6 +1,6 @@
 ################################################################################
 #
-# $Id: Options.pm 211 2009-05-25 06:05:50Z aijaz $
+# $Id: Options.pm 288 2010-03-21 01:08:33Z aijaz $
 #
 ################################################################################
 
@@ -45,6 +45,7 @@ use Data::Dumper;
 use Carp;
 use Config::General qw(ParseConfig);
 use Log::Log4perl qw(:levels);
+use Sys::Hostname;
 
 BEGIN {
     use vars qw($VERSION);
@@ -60,29 +61,44 @@ our $options = {};
 # Getopts::Long if the corresponding option stores a value, or undef
 # if the parameter represents a boolean value
 #
-my %all_options = (end_time          => 's',
-                   wait_time         => 's',
-                   log_dir           => 's',
-                   once_only         => undef, 
-                   collapse          => undef, 
-                   job_dir           => 's',
-                   family_dir        => 's',
-                   run_wrapper       => 's',
-                   email_failure_to  => 's',
-                   verbose           => undef,
-                   help              => undef,
-                   config_file       => 's',
-                   chained           => undef,
-                   log_threshold     => 's',
-                   log               => undef,
-                   log_file          => 's',
-                   err_file          => 's',
-                   log_status        => undef,
-                   ignore_regex      => 's@',
-                   default_time_zone => 's',
-                   date              => 's',
-                   calendar_dir      => 's',
-    );
+my %all_options = (
+    end_time               => 's',
+    wait_time              => 's',
+    log_dir                => 's',
+    once_only              => undef, 
+    collapse               => undef, 
+    job_dir                => 's',
+    family_dir             => 's',
+    run_wrapper            => 's',
+    email                  => 's',
+    verbose                => undef,
+    help                   => undef,
+    config_file            => 's',
+    chained                => undef,
+    log_threshold          => 's',
+    log                    => undef,
+    log_file               => 's',
+    err_file               => 's',
+    log_status             => undef,
+    ignore_regex           => 's@',
+    default_time_zone      => 's',
+    date                   => 's',
+    calendar_dir           => 's',
+    instructions_dir       => 's',
+    smtp_server            => 's',
+    smtp_port              => 's',
+    smtp_sender            => 's',
+    mail_from              => 's',
+    mail_reply_to          => 's',
+    mail_return_path       => 's',
+    smtp_timeout           => 's',
+    num_retries            => 's',
+    retry_sleep            => 's',
+    retry_email            => 's',
+    no_retry_email         => undef,
+    retry_success_email    => 's',
+    no_retry_success_email => undef,
+);
 
 # These are the required options. The absence of any one of these will
 # cause the program to die.
@@ -183,21 +199,36 @@ sub getOptions {
     
 
     # Finally, pick a default value if necessary
-    $tainted_options->{wait_time}         = 60                unless defined $tainted_options->{wait_time};
-    $tainted_options->{end_time}          = '2355'            unless defined $tainted_options->{end_time};
-    $tainted_options->{once_only}         = 0                 unless defined $tainted_options->{once_only};
-    $tainted_options->{verbose}           = 0                 unless defined $tainted_options->{verbose};
-    $tainted_options->{collapse}          = 0                 unless defined $tainted_options->{collapse};
-    $tainted_options->{chained}           = 0                 unless defined $tainted_options->{chained};
-    $tainted_options->{log}               = 0                 unless defined $tainted_options->{log};
-    $tainted_options->{log_threshold}     = 'info'            unless defined $tainted_options->{log_threshold};
-    $tainted_options->{log_file}          = "stdout"          unless defined $tainted_options->{log_file};
-    $tainted_options->{err_file}          = "stderr"          unless defined $tainted_options->{err_file};
-    $tainted_options->{log_status}        = 0                 unless defined $tainted_options->{log_status};
-    $tainted_options->{ignore_regex}      = []                unless defined $tainted_options->{ignore_regex};
-    $tainted_options->{default_time_zone} = 'America/Chicago' unless defined $tainted_options->{default_time_zone};
-    $tainted_options->{date}              = ''                unless defined $tainted_options->{date};
-    $tainted_options->{token}             = {}                unless defined $tainted_options->{token};
+    $tainted_options->{wait_time}              = 60                unless defined $tainted_options->{wait_time};
+    $tainted_options->{end_time}               = '2355'            unless defined $tainted_options->{end_time};
+    $tainted_options->{once_only}              = 0                 unless defined $tainted_options->{once_only};
+    $tainted_options->{verbose}                = 0                 unless defined $tainted_options->{verbose};
+    $tainted_options->{collapse}               = 0                 unless defined $tainted_options->{collapse};
+    $tainted_options->{chained}                = 0                 unless defined $tainted_options->{chained};
+    $tainted_options->{log}                    = 0                 unless defined $tainted_options->{log};
+    $tainted_options->{log_threshold}          = 'info'            unless defined $tainted_options->{log_threshold};
+    $tainted_options->{log_file}               = "stdout"          unless defined $tainted_options->{log_file};
+    $tainted_options->{err_file}               = "stderr"          unless defined $tainted_options->{err_file};
+    $tainted_options->{log_status}             = 0                 unless defined $tainted_options->{log_status};
+    $tainted_options->{ignore_regex}           = []                unless defined $tainted_options->{ignore_regex};
+    $tainted_options->{default_time_zone}      = 'America/Chicago' unless defined $tainted_options->{default_time_zone};
+    $tainted_options->{date}                   = ''                unless defined $tainted_options->{date};
+    $tainted_options->{token}                  = {}                unless defined $tainted_options->{token};
+    $tainted_options->{smtp_server}            = ''                unless defined $tainted_options->{smtp_server};
+    $tainted_options->{smtp_port}              = 25                unless defined $tainted_options->{smtp_port};
+    $tainted_options->{smtp_timeout}           = 60                unless defined $tainted_options->{smtp_timeout};
+    $tainted_options->{smtp_sender}            = ''                unless defined $tainted_options->{smtp_sender};
+    $tainted_options->{mail_from}              = ''                unless defined $tainted_options->{mail_from};
+    $tainted_options->{mail_reply_to}          = ''                unless defined $tainted_options->{mail_reply_to};
+    $tainted_options->{mail_return_path}       = ''                unless defined $tainted_options->{mail_return_path};
+    $tainted_options->{num_retries}            = 0                 unless defined $tainted_options->{num_retries};
+    $tainted_options->{retry_sleep}            = 60                unless defined $tainted_options->{retry_sleep};
+    $tainted_options->{email}                  = ''                unless defined $tainted_options->{email};
+    $tainted_options->{instructions_dir}       = ''                unless defined $tainted_options->{instructions_dir};
+    $tainted_options->{retry_email}            = ''                unless defined $tainted_options->{retry_email};
+    $tainted_options->{no_retry_email}         = 0                 unless defined $tainted_options->{no_retry_email};
+    $tainted_options->{retry_success_email}    = ''                unless defined $tainted_options->{retry_success_email};
+    $tainted_options->{no_retry_success_email} = 0                 unless defined $tainted_options->{no_retry_success_email};
 
     # show help
     if ($tainted_options->{help}) {
@@ -229,8 +260,8 @@ sub getOptions {
     # The non-booleans are scanned with regexes with the matches being
     # put into $new_options
     #
-    if (defined ($tainted_options->{email_failure_to})) {
-        if ($tainted_options->{email_failure_to} =~ m!^([a-z0-9_:\.\@]+)!i) { $new_options->{email_failure_to} = $1; } else { croak "Bad email_failure_to"; }
+    if ( ($tainted_options->{email})) {
+        if ($tainted_options->{email} =~ m!^([a-z0-9\-_:\.\@\+]+)!i) { $new_options->{email} = $1; } else { croak "Bad email"; }
     }
     if (defined ($tainted_options->{run_wrapper})) {
         if ($tainted_options->{run_wrapper} =~ m!^([a-z0-9/_:\\\.\-]+)!i) { $new_options->{run_wrapper} = $1; } else { croak "Bad run_wrapper"; }
@@ -283,8 +314,46 @@ sub getOptions {
         }
     }
     if (defined ($tainted_options->{calendar_dir})) {
-        if ($tainted_options->{calendar_dir} =~ m!^([a-z0-9/_:\\\.\-]+)!i) { $new_options->{calendar_dir} = $1; } else { croak "Bad calendar_dir"; }
+        if ($tainted_options->{calendar_dir} =~ m!^([a-z0-9/_:\\\.\-]*)!i) { $new_options->{calendar_dir} = $1; } else { croak "Bad calendar_dir"; }
     }
+    if ( ($tainted_options->{instructions_dir})) {
+        if ($tainted_options->{instructions_dir} =~ m!^([a-z0-9/_:\\\.\-]*)!i) { $new_options->{instructions_dir} = $1; } else { croak "Bad instructions_dir"; }
+    }
+    if ( ($tainted_options->{smtp_server})) {
+        if ($tainted_options->{smtp_server} =~ m!^([a-z0-9_\-\.]*)!i) { $new_options->{smtp_server} = $1; } else { croak "Bad smtp server"; }
+    }
+    if ( ($tainted_options->{smtp_sender})) {
+        if ($tainted_options->{smtp_sender} =~ m!^([a-z0-9_:\-\.\@\+]*)!i) { $new_options->{smtp_sender} = $1; } else { croak "Bad smtp sender"; }
+    }
+    if ( ($tainted_options->{mail_from})) {
+        if ($tainted_options->{mail_from} =~ m!^([a-z0-9_:\-\.\@\+]*)!i) { $new_options->{mail_from} = $1; } else { croak "Bad mail from"; }
+    }
+    if ( ($tainted_options->{mail_reply_to})) {
+        if ($tainted_options->{mail_reply_to} =~ m!^([a-z0-9_:\-\.\@\+]*)!i) { $new_options->{mail_reply_to} = $1; } else { croak "Bad reply to"; }
+    }
+    if ( ($tainted_options->{mail_return_path})) {
+        if ($tainted_options->{mail_return_path} =~ m!^([a-z0-9_:\-\.\@\+]*)!i) { $new_options->{mail_return_path} = $1; } else { croak "Bad return path"; }
+    }
+    if (defined ($tainted_options->{smtp_port})) {
+        if ($tainted_options->{smtp_port} =~ m!^(\d+)!i) { $new_options->{smtp_port} = $1; } else { croak "Bad smtp port"; }
+    }
+    if (defined ($tainted_options->{smtp_timeout})) {
+        if ($tainted_options->{smtp_timeout} =~ m!^(\d+)!i) { $new_options->{smtp_timeout} = $1; } else { croak "Bad smtp timeout"; }
+    }
+    if (defined ($tainted_options->{num_retries})) {
+        if ($tainted_options->{num_retries} =~ m!^(\d+)!i) { $new_options->{num_retries} = $1; } else { croak "Bad smtp timeout"; }
+    }
+    if (defined ($tainted_options->{retry_sleep})) {
+        if ($tainted_options->{retry_sleep} =~ m!^(\d+)!i) { $new_options->{retry_sleep} = $1; } else { croak "Bad smtp timeout"; }
+    }
+    if ( ($tainted_options->{retry_email})) {
+        if ($tainted_options->{retry_email} =~ m!^([a-z0-9\-_:\.\@\+]*)!i) { $new_options->{retry_email} = $1; } else { croak "Bad retry_email"; }
+    }
+    if ($tainted_options->{no_retry_email}) { $new_options->{no_retry_email} = 1; } else { $new_options->{no_retry_email} = 0; } 
+    if ( ($tainted_options->{retry_success_email})) {
+        if ($tainted_options->{retry_success_email} =~ m!^([a-z0-9\-_:\.\@\+]*)!i) { $new_options->{retry_success_email} = $1; } else { croak "Bad retry_success_email"; }
+    }
+    if ($tainted_options->{no_retry_success_email}) { $new_options->{no_retry_success_email} = 1; } else { $new_options->{no_retry_success_email} = 0; } 
 
 
     if (%$options) {
@@ -298,6 +367,8 @@ sub getOptions {
     }
     $options = $new_options;
 
+    $ENV{HOSTNAME} = hostname;
+
     print "options is ", Dumper($options)  if $options->{verbose};
 
     
